@@ -4,6 +4,8 @@ from dataclasses import dataclass
 @dataclass
 class ArgumentOptions:
     url: str
+    source: str
+    non_exist: list[str]
     charsets: list[str]
     length_min: int
     length_max: int
@@ -12,7 +14,7 @@ class ArgumentOptions:
     suffix: str
     begin_with: str
     backups: bool
-    backups_only: bool
+    backup_all: bool
     extensions: list[str]
     extensions_file: str
     recurse: bool
@@ -32,7 +34,6 @@ class ArgumentOptions:
     timeout: int
     content_length: int
     without_dns_cache: bool
-    without_availability: bool
     headers: list[tuple[str,str]]
     user_agent: str
     cookie: str
@@ -50,4 +51,7 @@ class ArgumentOptions:
     json: bool
     errors: bool
     silent: bool
-    cache: bool
\ No newline at end of file
+    cache: bool
+    socket_address: str
+    socket_port: str
+    process_ident: str
\ No newline at end of file
